import { SolAmount } from './Amount';
import type { Context } from './Context';
import type { Instruction, WrappedInstruction } from './Instruction';
import type { RpcConfirmTransactionOptions, RpcConfirmTransactionResult, RpcSendTransactionOptions } from './RpcInterface';
import { Signer } from './Signer';
import { AddressLookupTableInput, Blockhash, BlockhashWithExpiryBlockHeight, Transaction, TransactionSignature, TransactionVersion } from './Transaction';
export type TransactionBuilderItemsInput = WrappedInstruction | WrappedInstruction[] | TransactionBuilder | TransactionBuilder[];
export type TransactionBuilderOptions = {
    version?: TransactionVersion;
    addressLookupTables?: AddressLookupTableInput[];
    blockhash?: Blockhash | BlockhashWithExpiryBlockHeight;
};
export type TransactionBuilderSendAndConfirmOptions = {
    send?: RpcSendTransactionOptions;
    confirm?: Partial<RpcConfirmTransactionOptions>;
};
export declare class TransactionBuilder {
    protected readonly context: Pick<Context, 'rpc' | 'transactions' | 'payer'>;
    protected readonly items: WrappedInstruction[];
    protected readonly options: TransactionBuilderOptions;
    constructor(context: Pick<Context, 'rpc' | 'transactions' | 'payer'>, items?: WrappedInstruction[], options?: TransactionBuilderOptions);
    prepend(input: TransactionBuilderItemsInput): TransactionBuilder;
    append(input: TransactionBuilderItemsInput): TransactionBuilder;
    add(input: TransactionBuilderItemsInput): TransactionBuilder;
    splitAtIndex(index: number): [TransactionBuilder, TransactionBuilder];
    setVersion(version: TransactionVersion): TransactionBuilder;
    useLegacyVersion(): TransactionBuilder;
    useV0(): TransactionBuilder;
    setAddressLookupTables(addressLookupTables: AddressLookupTableInput[]): TransactionBuilder;
    getBlockhash(): Blockhash | undefined;
    setBlockhash(blockhash: Blockhash | BlockhashWithExpiryBlockHeight): TransactionBuilder;
    setLatestBlockhash(): Promise<TransactionBuilder>;
    getInstructions(): Instruction[];
    getSigners(): Signer[];
    getBytesCreatedOnChain(): number;
    getRentCreatedOnChain(): Promise<SolAmount>;
    getTransactionSize(): number;
    minimumTransactionsRequired(): number;
    fitsInOneTransaction(): boolean;
    build(): Transaction;
    buildWithLatestBlockhash(): Promise<Transaction>;
    buildAndSign(): Promise<Transaction>;
    send(options?: RpcSendTransactionOptions): Promise<TransactionSignature>;
    sendAndConfirm(options?: TransactionBuilderSendAndConfirmOptions): Promise<{
        signature: TransactionSignature;
        result: RpcConfirmTransactionResult;
    }>;
    protected parseItems(input: TransactionBuilderItemsInput): WrappedInstruction[];
}
export declare const transactionBuilder: (context: Pick<Context, 'rpc' | 'transactions' | 'payer'>, items?: WrappedInstruction[]) => TransactionBuilder;
